==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24IconifyAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$IconifyAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 5f837cf43ceb8983 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24IconifyAction.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$IconifyAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 5f837cf43ceb8983 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24IconifyAction_H_ */
